==> react-atom-panel-1.15.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["alpha", "color", "elevation", "horizontalAlign", "rounded", "src", "verticalAlign"];
import PropTypes from 'prop-types';
import ColorPanel from './ColorPanel.js';
import ImagePanel, { HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS } from './ImagePanel.js';
import { COLORS, ALPHA, BORDER_RADIUS, ELEVATION, isImagePanel } from './constants.js';
import { jsx as _jsx } from "react/jsx-runtime";

var AtomPanel = function AtomPanel(_ref) {
  var alpha = _ref.alpha,
      color = _ref.color,
      _ref$elevation = _ref.elevation,
      elevation = _ref$elevation === void 0 ? ELEVATION.NONE : _ref$elevation,
      _ref$horizontalAlign = _ref.horizontalAlign,
      horizontalAlign = _ref$horizontalAlign === void 0 ? HORIZONTAL_ALIGNMENTS.CENTER : _ref$horizontalAlign,
      _ref$rounded = _ref.rounded,
      rounded = _ref$rounded === void 0 ? BORDER_RADIUS.NONE : _ref$rounded,
      src = _ref.src,
      _ref$verticalAlign = _ref.verticalAlign,
      verticalAlign = _ref$verticalAlign === void 0 ? VERTICAL_ALIGNMENTS.CENTER : _ref$verticalAlign,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  return isImagePanel({
    src: src
  }) ? /*#__PURE__*/_jsx(ImagePanel, _extends({
    color: color,
    elevation: elevation,
    horizontalAlign: horizontalAlign,
    rounded: rounded,
    src: src,
    verticalAlign: verticalAlign
  }, props)) : /*#__PURE__*/_jsx(ColorPanel, _extends({
    alpha: alpha,
    color: color,
    elevation: elevation,
    rounded: rounded
  }, props));
};

AtomPanel.displayName = 'AtomPanel';
export default AtomPanel;
export { HORIZONTAL_ALIGNMENTS as atomPanelHorizontalAlign, VERTICAL_ALIGNMENTS as atomPanelVerticalAlign, COLORS as atomPanelColors, ALPHA as atomPanelAlpha, BORDER_RADIUS as atomPanelRounded, ELEVATION as atomPanelElevation };

==> react-atom-panel-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["alpha", "color", "elevation", "horizontalAlign", "rounded", "src", "verticalAlign"];
import PropTypes from 'prop-types';
import ColorPanel from './ColorPanel.js';
import { ALPHA, BORDER_RADIUS, COLORS, ELEVATION, isImagePanel } from './constants.js';
import ImagePanel, { HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS } from './ImagePanel.js';
import { jsx as _jsx } from "react/jsx-runtime";

var AtomPanel = function AtomPanel(_ref) {
  var alpha = _ref.alpha,
      color = _ref.color,
      _ref$elevation = _ref.elevation,
      elevation = _ref$elevation === void 0 ? ELEVATION.NONE : _ref$elevation,
      _ref$horizontalAlign = _ref.horizontalAlign,
      horizontalAlign = _ref$horizontalAlign === void 0 ? HORIZONTAL_ALIGNMENTS.CENTER : _ref$horizontalAlign,
      _ref$rounded = _ref.rounded,
      rounded = _ref$rounded === void 0 ? BORDER_RADIUS.NONE : _ref$rounded,
      src = _ref.src,
      _ref$verticalAlign = _ref.verticalAlign,
      verticalAlign = _ref$verticalAlign === void 0 ? VERTICAL_ALIGNMENTS.CENTER : _ref$verticalAlign,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  return isImagePanel({
    src: src
  }) ? /*#__PURE__*/_jsx(ImagePanel, _extends({
    color: color,
    elevation: elevation,
    horizontalAlign: horizontalAlign,
    rounded: rounded,
    src: src,
    verticalAlign: verticalAlign
  }, props)) : /*#__PURE__*/_jsx(ColorPanel, _extends({
    alpha: alpha,
    color: color,
    elevation: elevation,
    rounded: rounded
  }, props));
};

AtomPanel.displayName = 'AtomPanel';
export default AtomPanel;
export { HORIZONTAL_ALIGNMENTS as atomPanelHorizontalAlign, VERTICAL_ALIGNMENTS as atomPanelVerticalAlign, COLORS as atomPanelColors, ALPHA as atomPanelAlpha, BORDER_RADIUS as atomPanelRounded, ELEVATION as atomPanelElevation };
